summaryrefslogtreecommitdiff
path: root/lib/config/default.js
diff options
context:
space:
mode:
Diffstat (limited to 'lib/config/default.js')
-rw-r--r--lib/config/default.js8
1 files changed, 7 insertions, 1 deletions
diff --git a/lib/config/default.js b/lib/config/default.js
index 9e401f38..12254d47 100644
--- a/lib/config/default.js
+++ b/lib/config/default.js
@@ -56,10 +56,15 @@ module.exports = {
// socket.io
heartbeatInterval: 5000,
heartbeatTimeout: 10000,
+ // too busy timeout
+ tooBusyLag: 70,
// document
documentMaxLength: 100000,
// image upload setting, available options are imgur/s3/filesystem/azure
imageUploadType: 'filesystem',
+ lutim: {
+ url: 'https://framapic.org/'
+ },
imgur: {
clientID: undefined
},
@@ -138,6 +143,7 @@ module.exports = {
idpCert: undefined,
issuer: undefined,
identifierFormat: 'urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress',
+ disableRequestedAuthnContext: false,
groupAttribute: undefined,
externalGroups: [],
requiredGroups: [],
@@ -56,10 +56,15 @@ module.exports = {
// document
documentMaxLength: 100000,
- // image upload setting, available options are imgur/s3/filesystem/azure
+ // image upload setting, available options are imgur/s3/filesystem/azure/lutim
imageUploadType: 'filesystem',